#
# spec file for package curlftpfs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           curlftpfs
Version:        0.9.2
Release:        65.3
Summary:        Filesystem for mounting FTP hosts using FUSE and libcurl
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            http://curlftpfs.sourceforge.net/
Source:         %{name}-%{version}.tar.bz2
Patch0:         bug-580609.patch
Patch1:         curlftpfs-needs-pthread
Patch2:         bug-955687.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  curl-devel
BuildRequires:  fuse-devel
BuildRequires:  glib2-devel
BuildRequires:  libtool
Requires:       fuse

%description
CurlFtpFS is a filesystem for mount yast2-ftp-server (FTP hosts) based
on fuse (FUSE) and libcurl. Important features are:

- openssl (SSL support),

- connecting through squid (tunneling HTTP proxies)

- automatic reconnect on server timeout.



Authors:
--------
    Robson Braga Araujo <robsonbraga@gmail.com>

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1
%patch -P 2

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%{makeinstall}

%files
%defattr (-, root, root)
%{_bindir}/curlftpfs
%{_mandir}/*/%{name}.*

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
-  Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Fri Nov 20 2015 ernestopheles@googlemail.com
- bug-955687.patch: fixed memory leak. openSUSE bug boo#955687
  (Debian bug 587250)
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Mon May  7 2012 jeffm@suse.com
- curlftpfs requires building with -pthread
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Fri May 21 2010 mszeredi@suse.cz
- fix bug in file upload [bnc#580609]
* Wed May 28 2008 mszeredi@suse.de
- update to 0.9.2
  * fixes 'du' for files >= 4GB (bnc#381658).
  * open(O_RDWR) --> fail with ENOTSUP.
  * Fix ftpfs_truncate creating empty files with no permissions set.
  * Support streaming writes (bnc#281052).
  * Added option to use a custom command to list files.
  * Add ftp_method option to make it faster to browse directories.
  * Disable EPSV by default because it can cause the program to hang.
* Fri Aug 10 2007 bk@suse.de
- Add "Requires: fuse" to ensure that fuse is present (285101#c29)
* Thu Apr 12 2007 mszeredi@suse.cz
- update to 0.9.1
  * Ask for a password in the terminal so that it doesn't show in ps.
  * Support different codepages.
  * Cache files not found.
  * Support for SOCKS proxy.
  * Bug fixes.
* Mon Oct  2 2006 cthiel@suse.de
- update to 0.9
  * enable utf8 support
  * enable chmod and chown
* Sun May 28 2006 cthiel@suse.de
- removed bogus curlftpfs-0.8.patch
* Thu May 25 2006 cthiel@suse.de
- update to version 0.8
  * Chunk downloading is now supported. You can now stream your music or
    video, download more than one file, or browse the filesystem while you
    download.
* Sat Apr 15 2006 cthiel@suse.de
- update to version 0.7
  * Added big manpage with all options documented.
  * Bug fix for exporting the ftp mounted directory with samba.
* Tue Apr 11 2006 cthiel@suse.de
- initial package (version 0.6)
